==> otter-browser-0.9.09.tar.gz: otter-browser-0.9.09/src/core/WebBackend.h <==
/**************************************************************************
* Otter Browser: Web browser controlled by the user, not vice-versa.
* Copyright (C) 2013 - 2015 Michal Dutkiewicz aka Emdek <michal@emdek.pl>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
**************************************************************************/

#ifndef OTTER_WEBBACKEND_H
#define OTTER_WEBBACKEND_H

#include "Addon.h"
#include "SpellCheckManager.h"

namespace Otter
{

class ContentsWidget;
class WebWidget;

class WebBackend : public Addon
{
	Q_OBJECT

public:
	explicit WebBackend(QObject *parent = NULL);

	virtual WebWidget* createWidget(bool isPrivate = false, ContentsWidget *parent = NULL) = 0;
	virtual QString getEngineVersion() const = 0;
	virtual QString getUserAgent(const QString &pattern = QString()) const = 0;
	QUrl getUpdateUrl() const;
	virtual QList<SpellCheckManager::DictionaryInformation> getDictionaries() const;
	virtual bool requestThumbnail(const QUrl &url, const QSize &size) = 0;

signals:
	void thumbnailAvailable(const QUrl &url, const QPixmap &thumbnail, const QString &title);
};

}

#endif

==> otter-browser-0.9.12.tar.gz: otter-browser-0.9.12/src/core/WebBackend.h <==
/**************************************************************************
* Otter Browser: Web browser controlled by the user, not vice-versa.
* Copyright (C) 2013 - 2016 Michal Dutkiewicz aka Emdek <michal@emdek.pl>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
**************************************************************************/

#ifndef OTTER_WEBBACKEND_H
#define OTTER_WEBBACKEND_H

#include "AddonsManager.h"
#include "SpellCheckManager.h"

namespace Otter
{

class ContentsWidget;
class WebWidget;

class WebBackend : public Addon
{
	Q_OBJECT

public:
	explicit WebBackend(QObject *parent = nullptr);

	virtual WebWidget* createWidget(bool isPrivate = false, ContentsWidget *parent = nullptr) = 0;
	virtual QString getEngineVersion() const = 0;
	virtual QString getSslVersion() const = 0;
	virtual QString getUserAgent(const QString &pattern = QString()) const = 0;
	QUrl getUpdateUrl() const;
	virtual QList<SpellCheckManager::DictionaryInformation> getDictionaries() const;
	AddonType getType() const;
	virtual bool requestThumbnail(const QUrl &url, const QSize &size) = 0;

signals:
	void thumbnailAvailable(const QUrl &url, const QPixmap &thumbnail, const QString &title);
};

}

#endif
